@@ -451,8 +451,14 @@ $(function() {
 			// Add a default tab if it was the last tab
 			AddEditorTab();
 		} else {
+			// Find the last tab
+			var $lastTab = $("#myTab a:last");
+			
 			// Show the last editor tab which we added
-			$("#myTab a:last").tab('show');
+			$lastTab.tab('show');
+
+			// Update currentEditorId
+			currentEditorId = "editor" + $lastTab.attr("href").substring(1);
 		}
 	});
 
